# ~~Loss~~

~~Add utility function for easy combining of multiple loss functions~~

# Learning Rate

Add as many LR Decay strategies for different SoTA models, such as Swin and the rest.

# Optimizer

Add auto learning-rate calculator based on batch-size and number of ranks

# Distributed Training

Add functions for easifying the use of FSDP training scheme

# Training

Add classification functions for fastening the training process

***Cool Feature***: In order to fasten the process of further customizing the training and validation scripts, add a function that generates a `.py` file containing the required training functions. The file can be named something like `training_functions_torchutils.py`, or anything else.


Add cutmix_mixup automation adder.

# MLflow

Upload the mlflow scripts already written for easing-down the *flow* of development using MLflow.
